@@ -100,7 +100,7 @@ class BackupManager(GObject.Object):
             logging.error(_("No backup exists at {}").format(self.PRIMARY_BACKUP_PATH))
             return False
 
-        # Warn if attempting to merge a backup into existing notes
+        # Notify and quit if attempting to merge a backup into existing notes
         if self.__db.get_all_notes_count() > 0:
             logging.error(
                 # Translators: Log message
@@ -108,7 +108,7 @@ class BackupManager(GObject.Object):
             )
             return False
 
-        # Warn if attempting to restore a backup into a synced session
+        # Notify and quit if attempting to restore a backup into a synced session
         if iotas.config_manager.nextcloud_sync_configured():
             # Translators: Log message
             msg = _("Backup restoration isn't possible with Nextcloud Notes sync configured")
@@ -200,7 +200,7 @@ class BackupManager(GObject.Object):
                 self.__db.add_note(note)
 
     def __restore_note_with_matching_remote_id(self, note: Note, remote_id_note: Note) -> None:
-        if BackupManager.note_identical_match(note, remote_id_note):
+        if note.identical_to(remote_id_note):
             logging.debug(
                 # Translators: Log message, {} is a note title
                 _('Skipping restoration of existing identical note "{}"').format(note.title)
@@ -215,7 +215,7 @@ class BackupManager(GObject.Object):
             )
 
     def __restore_note_with_matching_title(self, note: Note, existing_note: Note):
-        if BackupManager.note_identical_match(note, existing_note):
+        if note.identical_to(existing_note):
             logging.debug(
                 # Translators: Log message, {} is a note title
                 _('Skipping restoration of existing identical note "{}"').format(note.title)
@@ -370,17 +370,3 @@ class BackupManager(GObject.Object):
             return None
 
         return note
-
-    @staticmethod
-    def note_identical_match(note1: Note, note2) -> bool:
-        return (
-            note1.title == note2.title
-            and note1.content == note2.content
-            and note1.favourite == note2.favourite
-            and note1.category == note2.category
-            and note1.last_modified == note2.last_modified
-            and note1.dirty == note2.dirty
-            and note1.locally_deleted == note2.locally_deleted
-            and note1.etag == note2.etag
-            and note1.remote_id == note2.remote_id
-        )
