@@ -13,8 +13,10 @@ FONT_SIZE = "font-size"
 LINE_LENGTH = "line-length"
 USE_MONOSPACE_FONT = "use-monospace-font"
 EDITOR_THEME = "editor-theme"
+HIDE_EDITOR_HEADERBAR = "auto-hide-editor-headerbar"
 HIDE_HEADERBAR_WHEN_FULLSCREEN = "hide-editor-headerbar-when-fullscreen"
 BACKUP_NOTE_EXTENSION = "backup-note-extension"
+PERSIST_SIDEBAR = "persist-sidebar"
 INDEX_CATEGORY_STYLE = "index-category-style"
 
 NEXTCLOUD_ENDPOINT = "nextcloud-endpoint"
@@ -27,13 +29,18 @@ SPELLING_ENABLED = "spelling-enabled"
 SPELLING_LANGUAGE = "spelling-language"
 
 SHOW_STARTUP_SECRET_SERVICE_FAILURE = "show-startup-secret-service-failure"
+SHOW_SYNCING_DEBUG_NOTIFICATION = "show-syncing-debug-notification"
 
 MARKDOWN_RENDER = "markdown-render-enabled"
 MARKDOWN_SYNTAX_HIGHLIGHTING = "markdown-syntax-highlighting-enabled"
 MARKDOWN_KEEP_WEBKIT_PROCESS = "markdown-keep-webkit-process"
 MARKDOWN_TEX_SUPPORT = "markdown-tex-support"
+MARKDOWN_USE_MONOSPACE_FONT = "markdown-use-monospace-font"
+MARKDOWN_RENDER_MONOSPACE_FONT_RATIO = "markdown-render-proportional-to-monospace-font-ratio"
+MARKDOWN_DEFAULT_TO_RENDER = "markdown-default-to-render"
 
 LAST_LAUNCHED_VERSION = "last-launched-version"
+SHOW_EXTENDED_PREFERENCES = "show-extended-preferences"
 
 
 def get_window_size() -> GLib.Variant:
@@ -237,6 +244,23 @@ def set_index_category_style(value: str) -> None:
     settings.set_string(INDEX_CATEGORY_STYLE, value)
 
 
+def get_persist_sidebar() -> bool:
+    """Get whether to persist the index sidebar (in large windows).
+
+    :return: Whether to hide
+    :rtype: bool
+    """
+    return settings.get_value(PERSIST_SIDEBAR)
+
+
+def set_persist_sidebar(value: bool) -> None:
+    """Set whether to persist the index sidebar (in large windows).
+
+    :param bool value: New value
+    """
+    settings.set_boolean(PERSIST_SIDEBAR, value)
+
+
 def get_editor_theme() -> str:
     """Get editor theme.
 
@@ -254,6 +278,23 @@ def set_editor_theme(value: str) -> None:
     settings.set_string(EDITOR_THEME, value)
 
 
+def get_hide_editor_headerbar() -> bool:
+    """Get whether to hide the editor headerbar.
+
+    :return: Whether to hide
+    :rtype: bool
+    """
+    return settings.get_value(HIDE_EDITOR_HEADERBAR)
+
+
+def set_hide_editor_headerbar(value: bool) -> None:
+    """Set whether to hide the editor headerbar.
+
+    :param bool value: New value
+    """
+    settings.set_boolean(HIDE_EDITOR_HEADERBAR, value)
+
+
 def get_hide_editor_headerbar_when_fullscreen() -> bool:
     """Get whether to hide the editor headerbar when fullscreen.
 
@@ -339,6 +380,57 @@ def set_markdown_tex_support(value: bool) -> None:
     settings.set_boolean(MARKDOWN_TEX_SUPPORT, value)
 
 
+def get_markdown_use_monospace_font() -> bool:
+    """Get whether to use a monospace font for the markdown render.
+
+    :return: Using monospace font
+    :rtype: bool
+    """
+    return settings.get_value(MARKDOWN_USE_MONOSPACE_FONT)
+
+
+def set_markdown_use_monospace_font(value: bool) -> None:
+    """Set whether to use a monospace font for the markdown render.
+
+    :param bool value: New value
+    """
+    settings.set_boolean(MARKDOWN_USE_MONOSPACE_FONT, value)
+
+
+def set_markdown_render_monospace_font_ratio(value: float) -> None:
+    """Set the adjustment in size from proportional to fixed width font.
+
+    :param bool value: New value
+    """
+    settings.set_double(MARKDOWN_RENDER_MONOSPACE_FONT_RATIO, value)
+
+
+def get_markdown_render_monospace_font_ratio() -> float:
+    """Get the adjustment in size from proportional to fixed width font.
+
+    :return: Ratio
+    :rtype: float
+    """
+    return settings.get_double(MARKDOWN_RENDER_MONOSPACE_FONT_RATIO)
+
+
+def get_markdown_default_to_render() -> bool:
+    """Get whether to render the markdown when opening the note.
+
+    :return: Defaulting to render
+    :rtype: bool
+    """
+    return settings.get_value(MARKDOWN_DEFAULT_TO_RENDER)
+
+
+def set_markdown_default_to_render(value: bool) -> None:
+    """Set whether to render the markdown when opening the note.
+
+    :param bool value: New value
+    """
+    settings.set_boolean(MARKDOWN_DEFAULT_TO_RENDER, value)
+
+
 def get_nextcloud_endpoint() -> str:
     """Get Nextcloud endpoint.
 
@@ -412,6 +504,15 @@ def get_show_startup_secret_service_failure() -> bool:
     return settings.get_value(SHOW_STARTUP_SECRET_SERVICE_FAILURE)
 
 
+def get_show_syncing_debug_notification() -> bool:
+    """Get whether to show sync debug notifications.
+
+    :return: Whether to show
+    :rtype: bool
+    """
+    return settings.get_value(SHOW_SYNCING_DEBUG_NOTIFICATION)
+
+
 def get_backup_note_extension() -> str:
     """Get file extension for backed up notes.
 
@@ -444,3 +545,20 @@ def set_last_launched_version(value: str) -> None:
     :param str value: New value
     """
     settings.set_string(LAST_LAUNCHED_VERSION, value)
+
+
+def get_show_extended_preferences() -> bool:
+    """Get whether to show a great many preferences.
+
+    :return: Whether to show
+    :rtype: bool
+    """
+    return settings.get_value(SHOW_EXTENDED_PREFERENCES)
+
+
+def set_show_extended_preferences(value: bool) -> None:
+    """Set whether to show a great many preferences.
+
+    :param bool value: New value
+    """
+    settings.set_boolean(SHOW_EXTENDED_PREFERENCES, value)
