@@ -1,18 +1,22 @@
-from gi.repository import Adw, Gio, GLib, GObject, Gtk, GtkSource
+from gi.repository import Gio, GLib, GObject, Gtk, GtkSource
 
 from typing import Optional
 
 
-@Gtk.Template(resource_path="/org/gnome/gitlab/cheywood/Iotas/ui/editor_search_header_bar.ui")
-class EditorSearchHeaderBar(Adw.Bin):
+@Gtk.Template(resource_path="/org/gnome/World/Iotas/ui/editor_search_header_bar.ui")
+class EditorSearchHeaderBar(Gtk.Box):
     __gtype_name__ = "EditorSearchHeaderBar"
     __gsignals__ = {
         "resumed": (GObject.SignalFlags.RUN_FIRST, None, ()),
+        "open-for-replace": (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
 
-    _entry = Gtk.Template.Child()
+    _search_entry = Gtk.Template.Child()
     _backward_button = Gtk.Template.Child()
     _forward_button = Gtk.Template.Child()
+    _revealer = Gtk.Template.Child()
+    _replace_entry = Gtk.Template.Child()
+    _replace_toggle = Gtk.Template.Child()
 
     def __init__(self):
         super().__init__()
@@ -21,39 +25,49 @@ class EditorSearchHeaderBar(Adw.Bin):
         self.__settings.set_wrap_around(True)
         self.__settings.bind_property(
             "search-text",
-            self._entry.text,
+            self._search_entry.text,
             "text",
             GObject.BindingFlags.BIDIRECTIONAL,
         )
         self.__context = None
         self.__offset_when_entered = 0
-        self.__jump_back_on_hide = False
         self.__context_signal_handler_id = None
         self.__cursor_signal_handler_id = None
         self.__current_match_tag = None
+        self.__active = False
+        self._search_entry.text.connect("notify::text", self.__on_search_text_changed)
+
+        self._revealer.bind_property(
+            "child-revealed", self._replace_toggle, "active", GObject.BindingFlags.SYNC_CREATE
+        )
 
     def setup(self, sourceview: GtkSource.View):
         """Perform initial setup."""
         self.__setup_actions()
         self.__sourceview = sourceview
 
-    def enter(self, resuming: bool) -> None:
+    def enter(self, resuming: bool, for_replace: bool) -> None:
         """Enter search.
 
         :param bool resuming: Whether resuming search
+        :param bool for_replace: Whether opening directly from a ctrl-h shortcut
         """
         buffer = self.__sourceview.get_buffer()
         self.__context = GtkSource.SearchContext.new(buffer, self.__settings)
         insert_iter = buffer.get_iter_at_mark(buffer.get_insert())
         self.__offset_when_entered = insert_iter.get_offset()
         self.__setup_current_match_styling()
+        if for_replace:
+            self._revealer.set_reveal_child(True)
         if not resuming:
-            self._entry.select_all_and_focus()
+            self._search_entry.select_all_and_focus()
 
         self.__context_signal_handler_id = self.__context.connect(
             "notify::occurrences-count", self.__occurrences_count_changed
         )
         self.__cursor_signal_handler_id = buffer.connect("cursor-moved", self.__on_cursor_moved)
+        self.__replace_action.set_enabled(False)
+        self.__active = True
 
     def exit(self) -> None:
         """Exit search."""
@@ -64,63 +78,97 @@ class EditorSearchHeaderBar(Adw.Bin):
         begin, end = buffer.get_bounds()
         buffer.remove_tag(self.__current_match_tag, begin, end)
         self.__current_match_tag = None
-        self.__jump_back_on_hide = False
+        self._revealer.set_reveal_child(False)
+        self.__active = False
 
-    @GObject.Property(type=bool, default=False)
-    def jump_back_on_hide(self) -> bool:
-        return self.__jump_back_on_hide
+    def disable_actions(self) -> None:
+        """Disable actions."""
+        self.__action_group.lookup_action("backward").set_enabled(False)
+        self.__action_group.lookup_action("forward").set_enabled(False)
 
-    @jump_back_on_hide.setter
-    def jump_back_on_hide(self, value: bool) -> None:
-        self.__jump_back_on_hide = value
-
-    def __on_backward(self, _obj: GObject.Object, result: Gio.AsyncResult) -> None:
-        success, match_start, match_end, __ = self.__context.backward_finish(result)
-        if success:
-            buffer = self.__sourceview.get_buffer()
-            buffer.select_range(match_start, match_end)
-            self.__current_match_tag.set_priority(buffer.get_tag_table().get_size() - 1)
-            self.__sourceview.scroll_to_insertion_point()
-            self.__jump_back_on_hide = False
-            self.__update_for_current_match(match_start, match_end)
-
-    def __on_forward(self, _obj: GObject.Object, result: Gio.AsyncResult) -> None:
-        success, match_start, match_end, __ = self.__context.forward_finish(result)
-        if success:
-            buffer = self.__sourceview.get_buffer()
-            buffer.select_range(match_start, match_end)
-            self.__current_match_tag.set_priority(buffer.get_tag_table().get_size() - 1)
-            self.__sourceview.scroll_to_insertion_point()
-            self.__jump_back_on_hide = False
-            self.__update_for_current_match(match_start, match_end)
-
-    def __on_cursor_moved(self, _obj: GObject.Object) -> None:
-        self.__update_for_current_match(None, None)
+    @Gtk.Template.Callback()
+    def _on_replace_entry_activate(self, _obj: GObject.Object) -> None:
+        if self.__replace_action.get_enabled():
+            self.__replace_selection()
 
     def __setup_actions(self) -> None:
         action_group = Gio.SimpleActionGroup.new()
         app = Gio.Application.get_default()
 
         action = Gio.SimpleAction.new("forward")
-        action.connect("activate", self.__move_forward)
+        action.connect("activate", self.__on_forward)
         action_group.add_action(action)
         app.set_accels_for_action("editor-search.forward", ["<Control>g"])
+        action.set_enabled(False)
 
         action = Gio.SimpleAction.new("backward")
-        action.connect("activate", self.__move_backward)
+        action.connect("activate", self.__on_backward)
         action_group.add_action(action)
         app.set_accels_for_action("editor-search.backward", ["<Shift><Control>g"])
+        action.set_enabled(False)
+
+        action = Gio.SimpleAction.new("toggle-replace")
+        action.connect("activate", self.__toggle_replace_visible)
+        action_group.add_action(action)
+        app.set_accels_for_action("editor-search.toggle-replace", ["<Control>h"])
+
+        action = Gio.SimpleAction.new("replace")
+        action.connect("activate", self.__on_replace_selection)
+        action_group.add_action(action)
+        self.__replace_action = action
 
         self.__action_group = action_group
         app.get_active_window().insert_action_group("editor-search", action_group)
 
-    def __jump_to_first(self) -> None:
-        buffer = self.__sourceview.get_buffer()
-        start_iter = buffer.get_iter_at_offset(self.__offset_when_entered)
-        success, match_start, __, __ = self.__context.forward(start_iter)
+    def __on_forward(
+        self,
+        _action: Gio.SimpleAction,
+        _param: GLib.Variant,
+    ) -> None:
+        self.__move_forward()
+
+    def __on_backward(
+        self,
+        _action: Gio.SimpleAction,
+        _param: GLib.Variant,
+    ) -> None:
+        self.__move_backward()
+
+    def __on_context_forward_cb(self, _obj: GObject.Object, result: Gio.AsyncResult) -> None:
+        success, match_start, match_end, __ = self.__context.forward_finish(result)
         if success:
-            self.__sourceview.scroll_to_iter(match_start, 0.25, True, 1, 0.5)
-            self.__jump_back_on_hide = True
+            buffer = self.__sourceview.get_buffer()
+            buffer.select_range(match_start, match_end)
+            self.__current_match_tag.set_priority(buffer.get_tag_table().get_size() - 1)
+            self.__sourceview.scroll_to_insertion_point()
+            self.__update_for_current_match(match_start, match_end)
+        self.__replace_action.set_enabled(success)
+
+    def __on_context_backward_cb(self, _obj: GObject.Object, result: Gio.AsyncResult) -> None:
+        success, match_start, match_end, __ = self.__context.backward_finish(result)
+        if success:
+            buffer = self.__sourceview.get_buffer()
+            buffer.select_range(match_start, match_end)
+            self.__current_match_tag.set_priority(buffer.get_tag_table().get_size() - 1)
+            self.__sourceview.scroll_to_insertion_point()
+            self.__update_for_current_match(match_start, match_end)
+        self.__replace_action.set_enabled(success)
+
+    def __on_cursor_moved(self, _obj: GObject.Object) -> None:
+        self.__update_for_current_match(None, None)
+        self.__replace_action.set_enabled(False)
+
+    def __on_search_text_changed(self, _obj: GObject.Object, _value: GObject.ParamSpec) -> None:
+        self.__replace_action.set_enabled(False)
+        self._search_entry.set_occurrence_count(0)
+        self._search_entry.set_occurrence_position(0)
+        # Clear any tagged matches when deleting the search term
+        buffer = self.__sourceview.get_buffer()
+        begin, end = buffer.get_bounds()
+        buffer.remove_tag(self.__current_match_tag, begin, end)
+
+    def __on_replace_selection(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
+        self.__replace_selection()
 
     def __occurrences_count_changed(
         self,
@@ -128,38 +176,15 @@ class EditorSearchHeaderBar(Adw.Bin):
         _value: GObject.ParamSpec,
     ) -> None:
         count = self.__context.get_occurrences_count()
-        self._entry.set_occurrence_count(count)
+        self._search_entry.set_occurrence_count(count)
         search_can_move = count > 0
-        if search_can_move:
-            self.__jump_to_first()
         self.__action_group.lookup_action("backward").set_enabled(search_can_move)
         self.__action_group.lookup_action("forward").set_enabled(search_can_move)
 
-    def __move_backward(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
-        """Move to previous search match."""
-        if self.__context is None:
-            if self._entry.get_text() != "":
-                self.emit("resumed")
-            else:
-                return
-        buffer = self.__sourceview.get_buffer()
-        if buffer.get_has_selection():
-            begin, end = buffer.get_selection_bounds()
-            begin.order(end)
-        else:
-            mark = buffer.get_insert()
-            begin = buffer.get_iter_at_mark(mark)
-        self.__context.backward_async(begin, None, self.__on_backward)
-        self.__jump_back_on_hide = False
-
-    def __move_forward(
-        self,
-        _action: Gio.SimpleAction,
-        _param: GLib.Variant,
-    ) -> None:
+    def __move_forward(self) -> None:
         """Move to next search match."""
         if self.__context is None:
-            if self._entry.get_text() != "":
+            if self._search_entry.get_text() != "":
                 self.emit("resumed")
             else:
                 return
@@ -170,8 +195,33 @@ class EditorSearchHeaderBar(Adw.Bin):
         else:
             mark = buffer.get_insert()
             end = buffer.get_iter_at_mark(mark)
-        self.__context.forward_async(end, None, self.__on_forward)
-        self.__jump_back_on_hide = False
+        self.__context.forward_async(end, None, self.__on_context_forward_cb)
+
+    def __move_backward(self) -> None:
+        """Move to previous search match."""
+        if self.__context is None:
+            if self._search_entry.get_text() != "":
+                self.emit("resumed")
+            else:
+                return
+        buffer = self.__sourceview.get_buffer()
+        if buffer.get_has_selection():
+            begin, end = buffer.get_selection_bounds()
+            begin.order(end)
+        else:
+            mark = buffer.get_insert()
+            begin = buffer.get_iter_at_mark(mark)
+        self.__context.backward_async(begin, None, self.__on_context_backward_cb)
+
+    def __toggle_replace_visible(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
+        if not self.__active:
+            self.emit("open-for-replace")
+            return
+        reveal = not self._revealer.get_child_revealed()
+        self._revealer.set_reveal_child(reveal)
+        if reveal:
+            self._replace_entry.grab_focus()
+            self.__replace_action.set_enabled(self.__have_search_term_selection())
 
     def __update_for_current_match(
         self, match_start: Optional[Gtk.TextIter], match_end: Optional[Gtk.TextIter]
@@ -185,10 +235,11 @@ class EditorSearchHeaderBar(Adw.Bin):
                 begin, end = bounds
                 begin.order(end)
                 new_position = self.__context.get_occurrence_position(begin, end)
-        self._entry.set_occurrence_position(new_position)
+        self._search_entry.set_occurrence_position(new_position)
 
-        begin, end = buffer.get_bounds()
-        buffer.remove_tag(self.__current_match_tag, begin, end)
+        if self.__current_match_tag is not None:
+            begin, end = buffer.get_bounds()
+            buffer.remove_tag(self.__current_match_tag, begin, end)
         if match_start is not None and match_end is not None:
             buffer.apply_tag(self.__current_match_tag, match_start, match_end)
             self.__current_match_tag.set_priority(buffer.get_tag_table().get_size() - 1)
@@ -207,3 +258,21 @@ class EditorSearchHeaderBar(Adw.Bin):
             if style is not None:
                 style.apply(self.__current_match_tag)
         self.__current_match_tag.set_priority(table.get_size() - 1)
+
+    def __replace_selection(self) -> None:
+        buffer = self.__sourceview.get_buffer()
+        if not self.__have_search_term_selection():
+            return
+        (start, end) = buffer.get_selection_bounds()
+        buffer.delete(start, end)
+        new_text = self._replace_entry.get_text()
+        if new_text != "":
+            buffer.insert(start, new_text)
+        self.__move_forward()
+
+    def __have_search_term_selection(self) -> bool:
+        buffer = self.__sourceview.get_buffer()
+        if not buffer.get_has_selection():
+            return False
+        (start, end) = buffer.get_selection_bounds()
+        return start.get_text(end).lower() == self._search_entry.get_text().lower()
