@@ -1,5 +1,5 @@
 from gettext import gettext as _
-from gi.repository import Gdk, GObject, Gio, GLib, Gtk
+from gi.repository import Adw, Gdk, GObject, Gio, GLib, Gtk
 
 import logging
 from typing import List, Optional
@@ -7,7 +7,7 @@ from typing import List, Optional
 from iotas.category import Category, CategorySpecialPurpose
 from iotas.category_manager import CategoryManager
 import iotas.config_manager
-import iotas.const
+from iotas import const
 from iotas.note import Note
 from iotas.note_manager import NoteManager
 from iotas.selection_header_bar import SelectionHeaderBar
@@ -15,18 +15,23 @@ from iotas.sync_manager import SyncManager
 from iotas.theme_selector import ThemeSelector
 
 
-@Gtk.Template(resource_path="/org/gnome/gitlab/cheywood/Iotas/ui/index.ui")
-class Index(Gtk.Box):
+@Gtk.Template(resource_path="/org/gnome/World/Iotas/ui/index.ui")
+class Index(Adw.BreakpointBin):
     __gtype_name__ = "Index"
 
     __gsignals__ = {
-        "note-opened": (GObject.SignalFlags.RUN_FIRST, None, (Note,)),
+        # Parameters are the note and whether to open immediately (disabling animation)
+        "note-opened": (GObject.SignalFlags.RUN_FIRST, None, (Note, bool)),
+        "reauthenticate": (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
 
     UNDO_NOTE_DELETION_DURATION = 5.0
     SYNC_CONFLICT_NOTIFICATION_DURATION = 5.0
+    SYNC_UPDATE_NOTIFICATION_DURATION = 2.0
+    BREAKPOINT_WIDTH = 700
 
-    _categories_flap = Gtk.Template.Child()
+    _split_view = Gtk.Template.Child()
+    _breakpoint = Gtk.Template.Child()
 
     _stack = Gtk.Template.Child()
     _sidebar = Gtk.Template.Child()
@@ -39,7 +44,7 @@ class Index(Gtk.Box):
 
     _header_stack = Gtk.Template.Child()
     _main_header_bar = Gtk.Template.Child()
-    _sidebar_button = Gtk.Template.Child()
+    _content_sidebar_button = Gtk.Template.Child()
     _search_header_bar = Gtk.Template.Child()
     _selection_header_bar = Gtk.Template.Child()
     _title = Gtk.Template.Child()
@@ -51,6 +56,8 @@ class Index(Gtk.Box):
     _new_button = Gtk.Template.Child()
 
     _offline_banner = Gtk.Template.Child()
+    _app_id_change_reauthenticate_banner = Gtk.Template.Child()
+    _generic_reauthenticate_banner = Gtk.Template.Child()
 
     def __init__(self):
         super().__init__()
@@ -62,7 +69,7 @@ class Index(Gtk.Box):
         self.__add_fav_action = None
         self.__remove_fav_action = None
         self.__initialised = False
-        self.__create_note_after_init = False
+        self.__search_after_init = None
         self.__searching_before_selection = False
         self.__active = False
 
@@ -96,9 +103,16 @@ class Index(Gtk.Box):
         self._search_header_bar.connect("changed", self.__on_search_changed)
 
         iotas.config_manager.settings.connect(
-            "changed::index-category-style", self.__category_style_changed
+            f"changed::{iotas.config_manager.INDEX_CATEGORY_STYLE}", self.__category_style_changed
         )
 
+        iotas.config_manager.settings.connect(
+            f"changed::{iotas.config_manager.PERSIST_SIDEBAR}", self.__on_persist_sidebar_changed
+        )
+
+        self._breakpoint.connect("apply", self.__on_breakpoint_apply)
+        self._breakpoint.connect("unapply", self.__on_breakpoint_unapply)
+
     def setup(
         self,
         note_manager: NoteManager,
@@ -147,6 +161,7 @@ class Index(Gtk.Box):
         self.__sync_manager.connect("ready", self.__on_sync_ready)
         self.__sync_manager.connect("started", self.__on_sync_started)
         self.__sync_manager.connect("finished", self.__on_sync_finished)
+        self.__sync_manager.connect("missing-password", self.__on_missing_password)
 
         self.__sync_manager.init_auth()
 
@@ -155,6 +170,10 @@ class Index(Gtk.Box):
         )
 
     def update_for_note_deletions(self, notes: List[Note]) -> None:
+        """Perform updates for deleted notes.
+
+        :param List[Note] notes: The deleted notes
+        """
         if len(notes) > 1:
             # Translators: Description, notification, {} is a positive number
             msg = _("{} notes deleted").format(len(notes))
@@ -175,6 +194,15 @@ class Index(Gtk.Box):
             self.__invalidate_view()
             self.__handle_emptied_category()
 
+    def update_layout_for_initial_width(self, width: int) -> None:
+        """Update layout for initial window width.
+
+        :param int width: Window width
+        """
+        self.__update_for_sidebar_persistence_change(width)
+        if not iotas.config_manager.get_persist_sidebar():
+            self._split_view.set_collapsed(True)
+
     def show_note_conflict_alert(self) -> None:
         """Let the user know a sync conflict has occurred with the note being edited."""
         self._timed_notification.show(
@@ -199,6 +227,10 @@ class Index(Gtk.Box):
         )
 
     def refresh_after_note_closed(self, note: Note) -> None:
+        """Refresh index afer note has been closed.
+
+        :param Note note: The closed note
+        """
         if self.__searching():
             self.__apply_search()
         else:
@@ -212,6 +244,16 @@ class Index(Gtk.Box):
         else:
             self._note_list.clear_selections()
 
+    def search_from_cli(self, search_term: str) -> None:
+        """Initiate a search, from the CLI.
+
+        :param str search_term: The search term
+        """
+        if self.__initialised:
+            self.__start_search_from_cli(search_term)
+        else:
+            self.__search_after_init = search_term
+
     @GObject.Property(type=bool, default=False)
     def active(self) -> bool:
         return self.__active
@@ -221,6 +263,10 @@ class Index(Gtk.Box):
         self.__active = value
         self.__enable_actions(value)
 
+    @Gtk.Template.Callback()
+    def _on_reauthenticate(self, _button: Gtk.Button) -> None:
+        self.emit("reauthenticate")
+
     def __on_search_changed(self, _object: GObject.Object) -> None:
         self.__apply_search()
 
@@ -243,6 +289,10 @@ class Index(Gtk.Box):
         action_group.add_action(action)
         app.set_accels_for_action("index.create-note", ["<Control>n"])
 
+        action = Gio.SimpleAction.new("create-note-with-content", GLib.VariantType("s"))
+        action.connect("activate", self.__on_create_note_with_content)
+        action_group.add_action(action)
+
         action = Gio.SimpleAction.new("delete-from-index")
         action.connect("activate", self.__on_delete_note_from_keyboard)
         action_group.add_action(action)
@@ -252,10 +302,10 @@ class Index(Gtk.Box):
         action.connect("activate", self.__load_older_notes)
         action_group.add_action(action)
 
-        action = Gio.SimpleAction.new("search")
-        action.connect("activate", self.__on_search)
+        action = Gio.SimpleAction.new("enter-search")
+        action.connect("activate", self.__on_enter_search)
         action_group.add_action(action)
-        app.set_accels_for_action("index.search", ["<Control>f"])
+        app.set_accels_for_action("index.enter-search", ["<Control>f"])
 
         action = Gio.SimpleAction.new("select-notes")
         action.connect("activate", self.__on_enter_selection)
@@ -305,11 +355,16 @@ class Index(Gtk.Box):
         _value: GObject.ParamSpec,
     ) -> None:
         """Create a new note and edit it."""
-        if not self.__initialised:
-            self.__create_note_after_init = True
-            return
         self.__create_and_open_note()
 
+    def __on_create_note_with_content(
+        self,
+        _obj: GObject.Object,
+        param: GObject.ParamSpec,
+    ) -> None:
+        """Create a new note with content and edit it."""
+        self.__create_and_open_note(param.get_string())
+
     def __on_notes_categories_changed(self, _obj: SelectionHeaderBar) -> None:
         changeset = self._selection_header_bar.get_categories_changeset()
         self.__cancel_selection()
@@ -337,10 +392,10 @@ class Index(Gtk.Box):
         self.__cancel_selection()
 
     def __on_note_opened(self, _obj: GObject.Object, note: Note) -> None:
-        self.emit("note-opened", note)
+        self.emit("note-opened", note, False)
 
     def __on_note_checkbox_activated(self, _obj: GObject.Object, note: Note) -> None:
-        if not self._selection_header_bar.active:
+        if not self.__selecting():
             self.__start_selection()
         self._selection_header_bar.set_note_selected(note, True)
 
@@ -350,8 +405,18 @@ class Index(Gtk.Box):
     def __on_category_header_bar_abort(self, _obj: SelectionHeaderBar) -> None:
         self.__cancel_selection()
 
-    def __on_category_activated(self, category: Category, close_flap: bool = True) -> None:
+    def __on_category_activated(self, category: Category, close_sidebar: bool = True) -> None:
         self.__category = category
+
+        # Handle clicking on category while searching or selecting with a persistent sidebar
+        if self.__searching():
+            self.__end_search()
+            # __end_search itself uses __on_category_activated
+            return
+        elif self.__selecting():
+            self.__searching_before_selection = False
+            self.__cancel_selection()
+
         self._title.set_label(category.display_name)
         self.__invalidate_view()
         if self.__category.special_purpose is None and not self._note_list.older_notes_loaded:
@@ -361,13 +426,16 @@ class Index(Gtk.Box):
         else:
             self._note_list.refresh_section_visibility(self.__category)
         self._note_list.update_category_labels(self.__category)
-        if close_flap and self._categories_flap.get_reveal_flap():
-            self._categories_flap.set_reveal_flap(False)
+        if close_sidebar and (
+            not iotas.config_manager.get_persist_sidebar()
+            or self.get_width() < self.BREAKPOINT_WIDTH
+        ):
+            self.__close_sidebar()
         if self.get_root().using_keyboard_navigation:
             self._note_list.move_focus_to_list_top()
 
-    def __on_search(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
-        self.__enter_search()
+    def __on_enter_search(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
+        self.__enter_search(True)
 
     def __on_enter_selection(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
         self.__start_selection()
@@ -375,28 +443,55 @@ class Index(Gtk.Box):
     def __on_sync_ready(self, _obj: GObject.Object, new_setup: bool) -> None:
         if new_setup and self.__searching():
             self.__end_search()
+        if self._app_id_change_reauthenticate_banner.get_revealed():
+            self._app_id_change_reauthenticate_banner.set_revealed(False)
+        if self._generic_reauthenticate_banner.get_revealed():
+            self._generic_reauthenticate_banner.set_revealed(False)
 
     def __on_sync_started(self, _obj: GObject.Object) -> None:
-        if self.active:
+        if self.active and iotas.config_manager.get_show_syncing_debug_notification():
             # Translators: Description, notification
             self._notification.show(_("Syncing"))
 
-    def __on_sync_finished(self, _obj: SyncManager, changes: bool) -> None:
+    def __on_sync_finished(self, _obj: SyncManager, changes: int) -> None:
         if self.active:
             self._notification.hide()
-            if changes:
+            if changes > 0:
                 self.__invalidate_view()
                 self._note_list.update_category_labels(self.__category)
 
+                if changes == 1:
+                    # Translators: Description, notification
+                    msg = _("1 change")
+                else:
+                    # Translators: Description, notification, {} is a number larger than 1
+                    msg = _("{} changes").format(changes)
+                self._timed_notification.show(
+                    msg, self.SYNC_UPDATE_NOTIFICATION_DURATION, show_icon=True
+                )
+
+    def __on_missing_password(self, _obj: GObject.Object) -> None:
+        app = Gio.Application.get_default()
+        previous_version = app.previous_version
+        if self.__sync_manager.configured_but_no_password:
+            if previous_version != "" and previous_version < const.APP_ID_CHANGE_VERSION:
+                self._app_id_change_reauthenticate_banner.set_revealed(True)
+            else:
+                self._generic_reauthenticate_banner.set_revealed(True)
+
     def __on_index_key_pressed(
         self,
         controller: Gtk.EventControllerKey,
         keyval: int,
         keycode: int,
         state: Gdk.ModifierType,
-    ):
+    ) -> bool:
         if keyval in (Gdk.KEY_Down, Gdk.KEY_KP_Down):
-            if self._categories_flap.get_reveal_flap():
+            if (
+                not iotas.config_manager.get_persist_sidebar()
+                and not self._split_view.get_collapsed()
+            ):
+                # If we have an auto-expanded sidebar use the shortcut to send the focus
                 self.get_root().using_keyboard_navigation = True
                 self._sidebar.take_focus()
             else:
@@ -405,11 +500,19 @@ class Index(Gtk.Box):
         elif keyval in (Gdk.KEY_Up, Gdk.KEY_KP_Up):
             self._note_list.move_focus_to_list_top()
             return Gdk.EVENT_STOP
-        elif not self.__searching() and not self._selection_header_bar.active:
+        elif not self.__searching() and not self.__selecting():
             result = self._search_header_bar.check_if_starting(controller, keyval, state)
-            if result == Gdk.EVENT_STOP:
+            if result:
                 self.__enter_search(False)
             return result
+        elif self.__searching():
+            if self._search_header_bar.check_for_open_first_result_shortcut(
+                controller, keyval, state
+            ):
+                # Check that we have some results, a litle indirect
+                if self._stack.get_visible_child() == self._note_list_scroll:
+                    self._note_list.open_first_search_result()
+                    return Gdk.EVENT_STOP
 
         return Gdk.EVENT_PROPAGATE
 
@@ -419,14 +522,14 @@ class Index(Gtk.Box):
         keyval: int,
         keycode: int,
         state: Gdk.ModifierType,
-    ):
+    ) -> bool:
         if keyval in (Gdk.KEY_Down, Gdk.KEY_KP_Down):
             self._note_list.focus_next_list_row(self.__get_focused())
             return Gdk.EVENT_STOP
         elif keyval in (Gdk.KEY_Up, Gdk.KEY_KP_Up):
             self._note_list.focus_previous_list_row(self.__get_focused())
             return Gdk.EVENT_STOP
-        elif not self.__searching() and not self._selection_header_bar.active:
+        elif not self.__searching() and not self.__selecting():
             result = self._search_header_bar.check_if_starting(controller, keyval, state)
             if result == Gdk.EVENT_STOP:
                 self.__enter_search(False)
@@ -437,7 +540,7 @@ class Index(Gtk.Box):
     def __on_delete_note_from_keyboard(
         self, _action: Gio.SimpleAction, _param: GLib.Variant
     ) -> None:
-        if self._selection_header_bar.active:
+        if self.__selecting():
             self._selection_header_bar.handle_delete_keyboard_shortcut()
         else:
             note = None
@@ -449,11 +552,11 @@ class Index(Gtk.Box):
                 self.__delete_notes([note])
 
     def __on_toggle_favourite(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
-        if self._selection_header_bar.active:
+        if self.__selecting():
             self._selection_header_bar.toggle_favourite_on_selection()
 
     def __on_category_shortcut(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
-        if self._selection_header_bar.active:
+        if self.__selecting():
             self._selection_header_bar.edit_category_for_selection()
         else:
             self.__toggle_sidebar()
@@ -461,9 +564,25 @@ class Index(Gtk.Box):
     def __on_toggle_sidebar(self, _action: Gio.SimpleAction, _param: GLib.Variant) -> None:
         self.__toggle_sidebar()
 
-    def __create_and_open_note(self) -> None:
+    def __on_breakpoint_apply(self, _bp: Adw.Breakpoint) -> None:
+        self._split_view.set_collapsed(True)
+        self.__update_header_buttons_for_state()
+
+    def __on_breakpoint_unapply(self, _bp: Adw.Breakpoint) -> None:
+        if iotas.config_manager.get_persist_sidebar():
+            self._split_view.set_collapsed(False)
+        else:
+            self._split_view.set_collapsed(True)
+        self.__update_header_buttons_for_state()
+
+    def __create_and_open_note(self, content: Optional[str] = None) -> None:
         note = self.__note_manager.create_note(self.__category)
-        self.emit("note-opened", note)
+        # If we're creating a note from a selection persist it straight away
+        if content is not None and content != "":
+            note.content = content
+            note.update_title_from_top_line()
+            self.__note_manager.persist_note_while_editing(note)
+        self.emit("note-opened", note, False)
 
     def __invalidate_view(self) -> None:
         """Refresh the view."""
@@ -486,17 +605,24 @@ class Index(Gtk.Box):
                 ):
                     self._stack.set_visible_child(self._note_list_scroll)
 
-    def __enter_search(self, clear_text: bool = True) -> None:
+    def __start_search_from_cli(self, search_term: str) -> None:
+        self._search_header_bar.text = search_term
+        self.__enter_search(False, True)
+
+    def __enter_search(self, clear_text, avoid_select_all: bool = False) -> None:
         """Enter the search UI."""
         if self.__searching():
+            # Grab focus and select entry text
+            self._note_list.clear_selections()
+            self._search_header_bar.enter(False, not avoid_select_all)
             return
 
-        self._search_header_bar.enter(clear_text)
+        self._search_header_bar.enter(clear_text, False)
 
         all_category = self._sidebar.select_and_fetch_category(None, CategorySpecialPurpose.ALL)
         self.__category = all_category
-        if self._categories_flap.get_reveal_flap():
-            self._categories_flap.set_reveal_flap(False)
+        if not iotas.config_manager.get_persist_sidebar() and not self._split_view.get_collapsed():
+            self._split_view.set_collapsed(True)
 
         self.__set_search_visible(True)
         if not self._note_list.older_notes_loaded:
@@ -526,13 +652,13 @@ class Index(Gtk.Box):
             self._note_list.restrict_for_search_by_ids(None)
 
     def __start_selection(self) -> None:
-        if self._categories_flap.get_reveal_flap():
-            self._categories_flap.set_reveal_flap(False)
+        if not iotas.config_manager.get_persist_sidebar() and not self._split_view.get_collapsed():
+            self._split_view.set_collapsed(True)
         self.__searching_before_selection = self.__searching()
         self._header_stack.set_visible_child(self._selection_header_bar)
         # Prevent focus jumping to top row of listbox and resulting scroll
         if not self.get_root().using_keyboard_navigation:
-            self._sidebar_button.grab_focus()
+            self._content_sidebar_button.grab_focus()
         self._selection_header_bar.activate()
         self.__update_enabled_actions(False)
 
@@ -550,11 +676,14 @@ class Index(Gtk.Box):
         else:
             self._note_list.clear_selections()
             # Prevent focus jumping to top row of listbox and resulting scroll
-            self._sidebar_button.grab_focus()
+            self._content_sidebar_button.grab_focus()
 
     def __searching(self) -> bool:
         return self._search_header_bar.active
 
+    def __selecting(self) -> bool:
+        return self._selection_header_bar.active
+
     def __set_search_visible(self, visible: bool) -> None:
         if visible:
             self._header_stack.set_visible_child(self._search_header_bar)
@@ -579,7 +708,7 @@ class Index(Gtk.Box):
             self._note_list.select_and_focus_note(note)
 
     def __update_enabled_actions(self, enable: bool) -> None:
-        for action in ("toggle-sidebar", "create-note", "search", "select-notes"):
+        for action in ("toggle-sidebar", "create-note", "enter-search", "select-notes"):
             action = self.__action_group.lookup(action)
             action.set_property("enabled", enable)
 
@@ -654,8 +783,8 @@ class Index(Gtk.Box):
 
         self.__initialised = True
         GLib.idle_add(self._note_list.update_category_labels, self.__category)
-        if self.__create_note_after_init:
-            GLib.idle_add(self.__create_and_open_note)
+        if self.__search_after_init is not None:
+            self.__start_search_from_cli(self.__search_after_init)
 
     def __on_new_note_persisted(self, _obj: GObject.Object) -> None:
         self.__invalidate_view()
@@ -724,29 +853,83 @@ class Index(Gtk.Box):
                 (category, _) = self.__category_manager.get_special_purpose_category(
                     CategorySpecialPurpose.ALL
                 )
+                # close_sidebar is False as we're closing it below
                 self.__on_category_activated(category, False)
-        if self._categories_flap.get_reveal_flap():
+        if not iotas.config_manager.get_persist_sidebar() and not self._split_view.get_collapsed():
             self.__close_sidebar()
-        elif self._selection_header_bar.active:
+        elif self.__selecting():
             self.__cancel_selection()
         elif self.__searching():
             self.__end_search()
 
     def __close_sidebar(self) -> None:
-        self._categories_flap.set_reveal_flap(False)
+        if self.get_width() < self.BREAKPOINT_WIDTH:
+            self._split_view.set_show_content(True)
+        else:
+            self._split_view.set_collapsed(True)
         if self.get_root().using_keyboard_navigation:
             self._note_list.grab_focus()
+        self.__update_header_buttons_for_state()
 
     def __toggle_sidebar(self) -> None:
-        if self._categories_flap.get_reveal_flap():
-            self.__close_sidebar()
+        if iotas.config_manager.get_persist_sidebar() and self.get_width() >= self.BREAKPOINT_WIDTH:
+            # Persistent sidebar is open, let's just throw the focus around
+            if self._sidebar.has_focus_within():
+                self.get_root().using_keyboard_navigation = True
+                self._note_list.grab_focus()
+            else:
+                self._sidebar.take_focus()
         else:
-            self._sidebar.take_focus()
-            self._categories_flap.set_reveal_flap(True)
+            if self.get_width() < self.BREAKPOINT_WIDTH:
+                # Thin / within breakpoint window, toggle sidebar and content
+                self._split_view.set_show_content(not self._split_view.get_show_content())
+            else:
+                # Wider / beyond breakpoint window
+                if self._split_view.get_collapsed():
+                    self._sidebar.take_focus()
+                    self._split_view.set_collapsed(False)
+                else:
+                    self._split_view.set_collapsed(True)
+                    if self.get_root().using_keyboard_navigation:
+                        self._note_list.grab_focus()
+            self.__update_header_buttons_for_state()
 
     def __category_style_changed(self, _obj: Gio.Settings, _key: str) -> None:
         self._note_list.update_category_labels(self.__category)
 
+    def __on_persist_sidebar_changed(self, _obj: Gio.Settings, _key: str) -> None:
+        self.__update_for_sidebar_persistence_change()
+
+    def __update_for_sidebar_persistence_change(self, width: int = -1) -> None:
+        if width == -1:
+            width = self.get_width()
+        persist = iotas.config_manager.get_persist_sidebar()
+        if persist:
+            self._split_view.set_collapsed(width < self.BREAKPOINT_WIDTH)
+        else:
+            self._split_view.set_collapsed(True)
+        self.__update_header_buttons_for_state(width)
+
+    def __update_header_buttons_for_state(self, width: int = -1) -> None:
+        if width == -1:
+            width = self.get_width()
+            # Used during initialisation
+            if width == 0:
+                width = self.get_property("width-request")
+        persist = iotas.config_manager.get_persist_sidebar()
+        if persist:
+            show_content_button = width < self.BREAKPOINT_WIDTH
+            show_sidebar_close = width < self.BREAKPOINT_WIDTH
+        else:
+            show_content_button = self._split_view.get_collapsed() and (
+                width >= self.BREAKPOINT_WIDTH or self._split_view.get_show_content()
+            )
+            show_sidebar_close = not show_content_button
+        show_sidebar_menu = persist and not self._split_view.get_collapsed()
+        self._content_sidebar_button.set_visible(show_content_button)
+        self._sidebar.show_buttons(show_sidebar_close, show_sidebar_menu)
+        self._menu_button.set_visible(not show_sidebar_menu)
+
     def __perform_initial_sync(self) -> None:
         self.__initial_sync_delay_complete = True
         self.__sync_manager.sync_now()
