@@ -10,7 +10,7 @@ from iotas.note_list_model import NoteListModelTimeFiltered
 from iotas.note_manager import NoteManager
 
 
-@Gtk.Template(resource_path="/org/gnome/gitlab/cheywood/Iotas/ui/index_note_list.ui")
+@Gtk.Template(resource_path="/org/gnome/World/Iotas/ui/index_note_list.ui")
 class IndexNoteList(Gtk.Box):
     __gtype_name__ = "IndexNoteList"
     __gsignals__ = {
@@ -324,6 +324,18 @@ class IndexNoteList(Gtk.Box):
         """
         self.__older_notes_model.restrict_by_id(ids)
 
+    def open_first_search_result(self) -> None:
+        """Open the top search result."""
+        listbox = self._older_notes_listbox
+        if listbox.get_visible():
+            row = listbox.get_row_at_index(0)
+            if row is None:
+                return
+            row.grab_focus()
+            listbox.select_row(row)
+            note = row.get_child().note
+            self.emit("note-opened", note)
+
     @GObject.Property(type=bool, default=False)
     def older_notes_displayed(self) -> bool:
         return self.__older_notes_displayed
