@@ -1,7 +1,7 @@
 import gi
 
 gi.require_version("WebKit", "6.0")
-from gi.repository import Gdk, GObject, WebKit
+from gi.repository import Gdk, Gio, GLib, GObject, WebKit
 
 import json
 import logging
@@ -17,6 +17,9 @@ from iotas import const
 from markdown_it_modified_tasklists_plugin.mdit_tasklists_with_elements_plugin import (
     tasklists_with_elements_plugin,
 )
+from markdown_it_img_lazyload_plugin.mdit_img_lazyload_plugin import (
+    img_lazyload_plugin,
+)
 
 
 class MarkdownRenderView(WebKit.WebView):
@@ -35,6 +38,9 @@ class MarkdownRenderView(WebKit.WebView):
         super().__init__()
         self.__user_stylesheet = None
         self.__scroll_position = 0
+        self.__font_family = ""
+        self.__engine_initialised = False
+        self.__searching = False
 
     def setup(self) -> None:
         """Setup for new WebKit instance."""
@@ -45,8 +51,21 @@ class MarkdownRenderView(WebKit.WebView):
         content_manager.register_script_message_handler("toPython")
         content_manager.connect("script-message-received", self.__handle_js_message)
         self.__content_manager = content_manager
-        iotas.config_manager.settings.connect("changed::font-size", self.__refresh_configurables)
-        iotas.config_manager.settings.connect("changed::line-length", self.__refresh_configurables)
+        iotas.config_manager.settings.connect(
+            f"changed::{iotas.config_manager.FONT_SIZE}", self.__on_style_setting_changed
+        )
+        iotas.config_manager.settings.connect(
+            f"changed::{iotas.config_manager.MARKDOWN_RENDER_MONOSPACE_FONT_RATIO}",
+            self.__on_style_setting_changed,
+        )
+        iotas.config_manager.settings.connect(
+            f"changed::{iotas.config_manager.LINE_LENGTH}", self.__on_style_setting_changed
+        )
+        app = Gio.Application.get_default()
+        self.__track_timing = app.debug_session or app.development_mode
+
+        self.connect("web-process-terminated", self.__log_terminated)
+
         # self.get_settings().set_enable_developer_extras(True)
 
     def render(
@@ -58,11 +77,12 @@ class MarkdownRenderView(WebKit.WebView):
         :param bool read_only: Whether note is read_only
         :param Optional[float] scroll_position: Position to scroll to
         """
-        self.__refresh_configurables()
+        self.__update_style()
 
         md = (
             markdown_it.MarkdownIt("gfm-like")
             .use(tasklists_with_elements_plugin, enabled=not read_only, div=True)
+            .use(img_lazyload_plugin)
             .enable("table")
         )
         if iotas.config_manager.get_markdown_tex_support():
@@ -149,6 +169,7 @@ class MarkdownRenderView(WebKit.WebView):
         <body>{content}</body>
         </html>
         """
+        self.__load_started_at = GLib.get_monotonic_time()
         self.load_html(content, "file://localhost/")
 
     def render_retaining_scroll(self, input_md: str, read_only: bool) -> None:
@@ -159,6 +180,14 @@ class MarkdownRenderView(WebKit.WebView):
         """
         self.render(input_md, read_only, self.scroll_position)
 
+    def update_font(self, font_family: str) -> None:
+        """Update the font family used in the render.
+
+        :param str font_family: The font family
+        """
+        self.__font_family = font_family
+        self.__update_style()
+
     @staticmethod
     def render_tex(eq: str, options: dict) -> str:
         """Render TeX markdown into HTML element.
@@ -219,10 +248,29 @@ class MarkdownRenderView(WebKit.WebView):
     def scroll_position(self, value: float) -> None:
         self.__scroll_position = value
 
+    @GObject.Property(type=bool, default=False)
+    def searching(self) -> bool:
+        return self.__searching
+
+    @searching.setter
+    def searching(self, value: bool) -> None:
+        self.__searching = value
+        self.__update_style()
+
     def __on_load_changed(self, _web_view: WebKit.WebView, load_event: WebKit.LoadEvent) -> None:
         if load_event == WebKit.LoadEvent.FINISHED:
+            if self.__track_timing:
+                duration = GLib.get_monotonic_time() - self.__load_started_at
+                if self.__engine_initialised:
+                    logging.debug(f"Render took {duration/1000:.2f}ms")
+                else:
+                    logging.debug(f"WebKit initialiation and render took {duration/1000:.2f}ms")
+                self.__engine_initialised = True
             self.emit("loaded")
 
+    def __on_style_setting_changed(self, _obj: GObject.Object, _value: GObject.ParamSpec) -> None:
+        self.__update_style()
+
     def __handle_js_message(self, _manager: WebKit.UserContentManager, result) -> None:
         js = result.to_json(2)
         message = json.loads(js)
@@ -269,17 +317,41 @@ class MarkdownRenderView(WebKit.WebView):
     def __handle_scroll_position(self, message: dict) -> None:
         self.scroll_position = message["position"]
 
-    def __refresh_configurables(
-        self, _obj: GObject.Object = None, _value: GObject.ParamSpec = None
-    ) -> None:
-        new_size = iotas.config_manager.get_font_size()
+    def __get_font_size(self) -> float:
+        monospace_editor = iotas.config_manager.get_use_monospace_font()
+        monospace_render = iotas.config_manager.get_markdown_use_monospace_font()
+        editor_size = iotas.config_manager.get_font_size()
+        ratio = iotas.config_manager.get_markdown_render_monospace_font_ratio()
+        if monospace_editor and not monospace_render:
+            size = editor_size / ratio
+        elif monospace_render and not monospace_editor:
+            size = editor_size * ratio
+        else:
+            size = editor_size
+        return size
+
+    def __update_style(self) -> None:
+        new_size = self.__get_font_size()
         new_length = iotas.config_manager.get_line_length()
+        backup_font = (
+            "monospace" if iotas.config_manager.get_markdown_use_monospace_font() else "sans-serif"
+        )
+        families = [self.__font_family, backup_font]
+        new_font_family = "; ".join(families)
+
+        searching_section = self.__build_searching_css()
+
         stylesheet = """body {
           font-size: %dpt;
           max-width: %dpx;
-        }""" % (
+          font-family: %s;
+        }
+
+        %s""" % (
             new_size,
             new_length,
+            new_font_family,
+            searching_section,
         )
         if self.__user_stylesheet is not None:
             self.__content_manager.remove_style_sheet(self.__user_stylesheet)
@@ -292,3 +364,27 @@ class MarkdownRenderView(WebKit.WebView):
             None,
         )
         self.__content_manager.add_style_sheet(self.__user_stylesheet)
+
+    def __build_searching_css(self) -> str:
+        if self.__searching:
+            css = """  ::selection {
+              color: var(--dark-6);
+              background-color: var(--yellow-4);
+            }
+
+            @media (prefers-color-scheme: dark) {
+              ::selection {
+                background-color: var(--yellow-1);
+              }
+            }
+            """
+        else:
+            css = ""
+        return css
+
+    def __log_terminated(
+        self, _web_view: WebKit.WebView, reason: WebKit.WebProcessTerminationReason
+    ) -> None:
+        if self.__track_timing:
+            logging.debug(f"WebKit process terminated for {reason}")
+        self.__engine_initialised = False
