@@ -1,6 +1,7 @@
 from gettext import gettext as _
 from gi.repository import Adw, Gdk, GLib, Gtk
 
+from enum import IntEnum, auto
 from threading import Thread
 from typing import Optional
 
@@ -9,7 +10,13 @@ from iotas.nextcloud_sync_worker import LoginRequestResult
 from iotas.sync_manager import SyncManager
 
 
-@Gtk.Template(resource_path="/org/gnome/gitlab/cheywood/Iotas/ui/nextcloud_login_window.ui")
+class LoginWindowMode(IntEnum):
+    NORMAL = auto()
+    REAUTHENTICATE = auto()
+    SECRET_SERVICE_FAILURE = auto()
+
+
+@Gtk.Template(resource_path="/org/gnome/World/Iotas/ui/nextcloud_login_window.ui")
 class NextcloudLoginWindow(Adw.Window):
     __gtype_name__ = "NextcloudLoginWindow"
 
@@ -28,19 +35,26 @@ class NextcloudLoginWindow(Adw.Window):
     _spinner = Gtk.Template.Child()
     _waiting_label = Gtk.Template.Child()
     _syncing_label = Gtk.Template.Child()
+    _resyncing_label = Gtk.Template.Child()
     _entry_notification = Gtk.Template.Child()
     _instance_label = Gtk.Template.Child()
 
     _self_signed_certificate_handling = Gtk.Template.Child()
 
-    def __init__(self, sync_manager: SyncManager, secret_service_failed: bool):
+    def __init__(self, sync_manager: SyncManager, mode: LoginWindowMode):
         super().__init__()
         self._continue_button.grab_focus()
         self.__sync_manager = sync_manager
+        self.__mode = mode
         self.__timeout_id = None
-        if secret_service_failed:
+        if mode == LoginWindowMode.SECRET_SERVICE_FAILURE:
             self._stack.set_visible_child(self._secret_service_failure)
             self._continue_button.set_sensitive(False)
+        elif mode == LoginWindowMode.REAUTHENTICATE:
+            endpoint = iotas.config_manager.get_nextcloud_endpoint()
+            if endpoint != "":
+                self._url_entry.set_text(endpoint)
+            self.__attempt_login()
 
         self.__sync_manager.connect("finished", self.__on_initial_sync_finished)
 
@@ -92,12 +106,15 @@ class NextcloudLoginWindow(Adw.Window):
         if storage_success:
             if self._stack.get_visible_child() == self._loading:
                 self._waiting_label.set_visible(False)
-                self._syncing_label.set_visible(True)
+                if self.__mode == LoginWindowMode.REAUTHENTICATE:
+                    self._resyncing_label.set_visible(True)
+                else:
+                    self._syncing_label.set_visible(True)
         else:
             self._stack.set_visible_child(self._secret_service_failure)
             self._spinner.stop()
 
-    def __on_initial_sync_finished(self, _obj: SyncManager, _changes: bool) -> None:
+    def __on_initial_sync_finished(self, _obj: SyncManager, _changes: int) -> None:
         self._spinner.stop()
         self._stack.set_visible_child(self._finished)
         self._cancel_button.set_sensitive(False)
@@ -151,6 +168,7 @@ class NextcloudLoginWindow(Adw.Window):
     def __attempt_login(self) -> None:
         self._waiting_label.set_visible(True)
         self._syncing_label.set_visible(False)
+        self._resyncing_label.set_visible(False)
         self._stack.set_visible_child(self._loading)
         self._spinner.start()
         self._continue_button.set_sensitive(False)
