@@ -30,6 +30,7 @@ class NextcloudSyncWorker(GObject.Object):
         "api-check-finished": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "settings-fetched": (GObject.SignalFlags.RUN_FIRST, None, (str,)),
         "secret-service-failure": (GObject.SignalFlags.RUN_FIRST, None, ()),
+        "missing-password": (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
 
     ENDPOINT_V_1_0 = "/index.php/apps/notes/api/v1/"
@@ -40,7 +41,7 @@ class NextcloudSyncWorker(GObject.Object):
 
     SECRET_ATTRIBUTES = {"service": "nextcloud"}
     SECRET_SCHEMA = Secret.Schema.new(
-        "org.gnome.gitlab.cheywood.Iotas",
+        "org.gnome.World.Iotas",
         Secret.SchemaFlags.NONE,
         {"service": Secret.SchemaAttributeType.STRING},
     )
@@ -113,7 +114,7 @@ class NextcloudSyncWorker(GObject.Object):
 
         try:
             response = res.json()
-        except JSONDecodeError as e:
+        except requests.exceptions.JSONDecodeError as e:
             logging.warning("Failed to decode login request to JSON: {} for {}".format(e, res.text))
             return (LoginRequestResult.FAILURE_GENERIC, None, None)
 
@@ -316,21 +317,20 @@ class NextcloudSyncWorker(GObject.Object):
         # Doing this sync fetch works around some type of libsecret flatpak issue (... so we may
         # as well use the result)
         self.__app_password = self.__fetch_password()
-        if self.__app_password is not None:
+        if self.__app_password is None:
+            self.emit("missing-password")
+        else:
             self.__check_setup()
         logging.debug("Nextcloud sync setup: {}".format(self.__authenticated))
 
-    def __check_setup(self) -> bool:
-        authenticated = False
+    def __check_setup(self) -> None:
         if (
             self.__server.strip() != ""
             and self.__username.strip() != ""
             and self.__app_password is not None
         ):
-            authenticated = True
             self.authenticated = True
             self.emit("ready", False)
-        return authenticated
 
     def __authenticated_and_password_stored(
         self, endpoint: str, username: str, app_password: str
@@ -408,7 +408,7 @@ class NextcloudSyncWorker(GObject.Object):
     def __store_password(self, login: str, password: str) -> bool:
         success = False
         try:
-            item_id = "org.gnome.gitlab.cheywood.Iotas: {}".format(login)
+            item_id = "org.gnome.World.Iotas: {}".format(login)
             success = Secret.password_store_sync(
                 self.SECRET_SCHEMA,
                 self.SECRET_ATTRIBUTES,
