@@ -195,6 +195,36 @@ class Note(GObject.Object):
                 title = title[:200]
             self.title = title
 
+    def identical_excepting_sync_update(self, note2: Note) -> bool:
+        """Check whether notes are identical, apart from sync update fields.
+
+        :param Note note2: Note to compare to
+        :return: Whether matching
+        :rtype: bool
+        """
+        return (
+            self.title == note2.title
+            and self.content == note2.content
+            and self.favourite == note2.favourite
+            and self.category == note2.category
+            and self.locally_deleted == note2.locally_deleted
+            and self.remote_id == note2.remote_id
+        )
+
+    def identical_to(self, note2: Note) -> bool:
+        """Check whether notes are identical.
+
+        :param Note note2: Note to compare to
+        :return: Whether identical
+        :rtype: bool
+        """
+        return (
+            self.identical_excepting_sync_update(note2)
+            and self.last_modified == note2.last_modified
+            and self.dirty == note2.dirty
+            and self.etag == note2.etag
+        )
+
     @staticmethod
     def from_backup(meta: dict, content: str) -> Optional[Note]:
         """Create note from backup dict.
