@@ -141,6 +141,13 @@ class NoteManager(GObject.Object):
         """
         return self.__base_model.fetch_note_by_remote_id(remote_id)
 
+    def fetch_note_by_id(self, db_id: int) -> Optional[Note]:
+        """Fetch a note by database id"
+
+        :param int db_id: The database id of the note
+        """
+        return self.__base_model.fetch_note_by_db_id(db_id)
+
     def invalidate_sort(self) -> None:
         """Invalidate the sorter."""
         self.__base_model.invalidate_sort()
@@ -155,7 +162,7 @@ class NoteManager(GObject.Object):
         note.repopulate_meta_from_sync_update(sync_result.data)
         clear_dirty = not note.dirty_while_saving
         self.__db.persist_note_remote_meta_and_sanitisable_fields(note, clear_dirty)
-        self.__base_model.ensure_map_entry(note)
+        self.__base_model.ensure_remote_map_entry(note)
 
     def on_deletion_undo_elapsed(self) -> None:
         """Push local deletions to server and flush local queue upon undo lapse."""
@@ -407,7 +414,7 @@ class NoteManager(GObject.Object):
         last_two_month_count = self.get_filtered_note_count(False)
 
         if total_note_count == 0 or total_note_count == last_two_month_count:
-            return False
+            return True
 
         few_total_notes = total_note_count < self.STARTUP_LOAD_ALL_NOTES_TOTAL_THRESHOLD
         few_notes_in_last_two_months = (
