@@ -1,4 +1,4 @@
-from gi.repository import Gdk, Gio, GObject, Gtk
+from gi.repository import Adw, Gdk, Gio, GObject, Gtk
 
 from typing import Callable, Optional
 
@@ -6,13 +6,16 @@ from iotas.category import Category, CategorySpecialPurpose
 from iotas.category_manager import CategoryManager
 from iotas.sidebar_row import SidebarRow
 from iotas.sync_manager import SyncManager
+from iotas.theme_selector import ThemeSelector
 
 
-@Gtk.Template(resource_path="/org/gnome/gitlab/cheywood/Iotas/ui/sidebar.ui")
-class Sidebar(Gtk.Box):
+@Gtk.Template(resource_path="/org/gnome/World/Iotas/ui/sidebar.ui")
+class Sidebar(Adw.Bin):
     __gtype_name__ = "Sidebar"
 
     _listview = Gtk.Template.Child()
+    _close_button = Gtk.Template.Child()
+    _menu_button = Gtk.Template.Child()
 
     def __init__(self):
         super().__init__()
@@ -36,6 +39,7 @@ class Sidebar(Gtk.Box):
         self.__category_activated_func = category_activated_func
         self.__filter_model.set_model(self.__category_manager.list_model)
         self.__category_manager.connect("initial-load-complete", self.__populate)
+        self._menu_button.get_popover().add_child(ThemeSelector(), "theme")
 
     def select_and_fetch_category(
         self,
@@ -60,6 +64,37 @@ class Sidebar(Gtk.Box):
     def take_focus(self) -> None:
         """Grab keyboard focus."""
         self._listview.grab_focus()
+        # Ensure one of the rows has focus, but don't force it to the top row
+        if self._listview.has_focus():
+            for row in self._listview:
+                row.grab_focus()
+                break
+
+    def has_focus_within(self) -> bool:
+        """Fetch whether the sidebar or any of its rows have focus.
+
+        :return: Whethe focused
+        :rtype: bool
+        """
+        # There's considerably more complexity here than expected due to Gtk.Widget.is_ancestor
+        # not behaving as expected.
+        if self._listview.has_focus():
+            return True
+        else:
+            for row in self._listview:
+                sidebar_row = row.get_first_child()
+                if sidebar_row.has_focus():
+                    return True
+        return False
+
+    def show_buttons(self, close_visible: bool, menu_visible: bool) -> None:
+        """Set visibility on buttons.
+
+        :param bool close_visible: Close button visibility
+        :param bool menu_visible: Menu button visibility
+        """
+        self._close_button.set_visible(close_visible)
+        self._menu_button.set_visible(menu_visible)
 
     def __init_listview(self) -> None:
         self.__factory = Gtk.SignalListItemFactory()
