@@ -40,10 +40,11 @@ class SyncManager(GObject.Object):
     __gsignals__ = {
         "ready": (GObject.SignalFlags.RUN_FIRST, None, (bool,)),
         "started": (GObject.SignalFlags.RUN_FIRST, None, ()),
-        "finished": (GObject.SignalFlags.RUN_FIRST, None, (bool,)),
+        "finished": (GObject.SignalFlags.RUN_FIRST, None, (int,)),
         "note-conflict": (GObject.SignalFlags.RUN_FIRST, None, (Note,)),
         "secret-service-failure": (GObject.SignalFlags.RUN_FIRST, None, ()),
         "remote-category-sanitised": (GObject.SignalFlags.RUN_FIRST, None, (str, str)),
+        "missing-password": (GObject.SignalFlags.RUN_FIRST, None, ()),
     }
 
     STARTUP_SYNC_INIT_DURATION = 500
@@ -68,7 +69,9 @@ class SyncManager(GObject.Object):
         self.__offline = False
         self.__sync_fail_counter = 0
 
-        iotas.config_manager.settings.connect("changed::sync-interval", self.__set_sync_interval)
+        iotas.config_manager.settings.connect(
+            f"changed::{iotas.config_manager.SYNC_INTERVAL}", self.__set_sync_interval
+        )
         self.__set_sync_interval()
 
         self.__sync_worker.connect("ready", self.__on_sync_ready)
@@ -78,6 +81,7 @@ class SyncManager(GObject.Object):
         self.__sync_worker.bind_property(
             "authenticated", self, "authenticated", GObject.BindingFlags.SYNC_CREATE
         )
+        self.__sync_worker.connect("missing-password", self.__on_missing_password)
 
     def init_auth(self) -> None:
         """Initialise sync authentication details from the Secret Service."""
@@ -165,6 +169,14 @@ class SyncManager(GObject.Object):
     def authenticated(self, new_val: bool) -> None:
         self.__authenticated = new_val
 
+    @GObject.Property(type=bool, default=False)
+    def configured_but_no_password(self) -> bool:
+        return (
+            iotas.config_manager.get_nextcloud_endpoint() != ""
+            and iotas.config_manager.get_nextcloud_username() != ""
+            and not self.authenticated
+        )
+
     @GObject.Property(type=bool, default=False)
     def offline(self) -> bool:
         return self.__offline
@@ -211,7 +223,7 @@ class SyncManager(GObject.Object):
             # the issue
             self.__api_check_and_settings_sync()
 
-            self.__finish_sync(False)
+            self.__finish_sync(0)
             self.__sync_fail_counter += 1
             if not self.__offline and self.__sync_fail_counter >= self.SYNC_FAIL_OFFLINE_THRESHOLD:
                 logging.info("Flagging offline")
@@ -284,7 +296,7 @@ class SyncManager(GObject.Object):
         # currently impacting behaviour; this may move.
         self.__api_check_and_settings_sync()
 
-        self.__finish_sync(changes_in + changes_out > 0)
+        self.__finish_sync(changes_in + changes_out)
 
     def __determine_remote_new_and_update(
         self, notes: List[Note], remote_ids_from_db: List[int], force_refresh_all: bool = False
@@ -305,13 +317,17 @@ class SyncManager(GObject.Object):
                     if note is None:
                         continue
                     if note.dirty:
-                        logging.info(
-                            "Sync. conflict, note %s was modified locally and updated remotely",
-                            note.title,
-                        )
-                        GLib.idle_add(self.emit, "note-conflict", note)
-                        # Duplicate existing note
-                        GLib.idle_add(self.__duplicate_note_for_sync_conflict, note)
+                        update_note = Note.from_nextcloud(sync_note)
+                        if not note.content_loaded:
+                            self.__db.populate_note_content(note)
+                        if not note.identical_excepting_sync_update(update_note):
+                            logging.info(
+                                "Sync. conflict, note %s was modified locally and updated remotely",
+                                note.title,
+                            )
+                            GLib.idle_add(self.emit, "note-conflict", note)
+                            # Duplicate existing note
+                            GLib.idle_add(self.__duplicate_note_for_sync_conflict, note)
                         note.dirty = False
                         self.__db.persist_note_dirty(note)
 
@@ -323,7 +339,7 @@ class SyncManager(GObject.Object):
             note = self.__note_manager.fetch_note_by_remote_id(remote_id)
             if note is None:
                 continue
-            if note.dirty:
+            if note.dirty and not note.locally_deleted:
                 GLib.idle_add(self.emit, "note-conflict", note)
                 # Duplicate existing note
                 logging.info(
@@ -383,8 +399,8 @@ class SyncManager(GObject.Object):
             idle_add_wait(self.__note_manager.remove_notes_from_model, local_del)
         return local_del
 
-    def __finish_sync(self, have_changes: bool) -> None:
-        GLib.idle_add(self.emit, "finished", have_changes)
+    def __finish_sync(self, number_of_changes: int) -> None:
+        GLib.idle_add(self.emit, "finished", number_of_changes)
         if self.__sync_requested_while_active:
             self.__lock.release()
             self.__sync()
@@ -462,6 +478,12 @@ class SyncManager(GObject.Object):
         if new_setup or self.__initial_sync_delay_complete:
             self.sync_now()
 
+    def __on_missing_password(self, _obj: GObject.Object) -> None:
+        logging.info(
+            "Sync is configured but password missing. Login to the server to reauthenticate."
+        )
+        self.emit("missing-password")
+
     def __on_api_check_finished(self, _obj: GObject.Object) -> None:
         self.__api_check_complete = True
         thread = Thread(target=self.__sync_worker.fetch_settings)
