@@ -5,7 +5,7 @@ from typing import Optional
 import iotas.config_manager
 
 
-@Gtk.Template(resource_path="/org/gnome/gitlab/cheywood/Iotas/ui/theme_selector.ui")
+@Gtk.Template(resource_path="/org/gnome/World/Iotas/ui/theme_selector.ui")
 class ThemeSelector(Gtk.Box):
     __gtype_name__ = "ThemeSelector"
 
@@ -16,7 +16,9 @@ class ThemeSelector(Gtk.Box):
     def __init__(self):
         super().__init__()
         self.__populate()
-        iotas.config_manager.settings.connect("changed::style-variant", self.__populate)
+        iotas.config_manager.settings.connect(
+            f"changed::{iotas.config_manager.STYLE}", self.__populate
+        )
 
     def __populate(self, _settings: Optional[Gio.Settings] = None, _key: str = "") -> None:
         style = iotas.config_manager.get_style()
