@@ -9,8 +9,10 @@ from iotas.editor_text_view import EditorTextView
 from iotas.first_start_page import FirstStartPage
 from iotas.font_size_selector import FontSizeSelector
 from iotas.index import Index
+from iotas.index_menu_button import IndexMenuButton
 from iotas.index_note_list import IndexNoteList
 from iotas.index_search_header_bar import IndexSearchHeaderBar
+from iotas.render_search_header_bar import RenderSearchHeaderBar
 from iotas.revealer_notification import RevealerNotification
 from iotas.selection_header_bar import SelectionHeaderBar
 from iotas.sidebar import Sidebar
@@ -33,8 +35,10 @@ def load_widgets() -> None:
     GObject.type_ensure(FirstStartPage)
     GObject.type_ensure(FontSizeSelector)
     GObject.type_ensure(Index)
+    GObject.type_ensure(IndexMenuButton)
     GObject.type_ensure(IndexNoteList)
     GObject.type_ensure(IndexSearchHeaderBar)
+    GObject.type_ensure(RenderSearchHeaderBar)
     GObject.type_ensure(RevealerNotification)
     GObject.type_ensure(SelectionHeaderBar)
     GObject.type_ensure(Sidebar)
